#
# spec file for package vaapi-intel-driver
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define srcname libva-intel-driver

Name:           vaapi-intel-driver
Version:        1.5.0
Release:        1.1
Summary:        Intel Driver for Video Acceleration (VA) API for Linux
License:        MIT and EPL-1.0
Group:          System/Libraries
Url:            http://freedesktop.org/wiki/Software/vaapi
Source0:        http://www.freedesktop.org/software/vaapi/releases/%{srcname}/%{srcname}-%{version}.tar.bz2
# Intel graphics hardware only available on these platforms
ExclusiveArch:  %ix86 x86_64
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  pkgconfig(libdrm) >= 2.4.45
BuildRequires:  pkgconfig(libdrm_intel)
BuildRequires:  pkgconfig(libva-x11) >= 0.37

%description
Intel Driver for Libva is a library providing the VA API video acceleration API.

%prep
%setup -q -n %{srcname}-%{version}

%build
autoreconf -fiv
%configure --disable-silent-rules --disable-static --with-pic
make %{?_smp_mflags}

%install
make install DESTDIR=%{buildroot}

find %{buildroot} -name "*.la" -delete

%clean
rm -rf %{buildroot}

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%dir %{_libdir}/dri
%{_libdir}/dri/i965_drv_video.so

%changelog
* Sun Feb  8 2015 zaitor@opensuse.org
- Update to version 1.5.0:
  + Add support for Skylake.
  - Decoding: H.264/MPEG-2/VC-1/JPEG/VP8/HEVC.
  - Encoding: H.264/MPEG-2/JPEG.
  - VPP: CSC/scaling/NoiseReduction/Deinterlacing{Bob,
    MotionAdaptive, MotionCompensated}/ColorBalance/STD.
  + Add support for JPEG encoding on Braswell.
  + Add enhancement for video post/pre processing.
  + Fix out of tree builds.
* Mon Oct 27 2014 sndirsch@suse.com
- Update to 1.4.1; changes since release 1.2.0:
  * support for more GPUs
  * bunch of fixes
  * new features
* Wed Jul 10 2013 hrvoje.senjan@gmail.com
- Update to 1.2.0:
  * Support the new H.264 encoding API on SNB/IVB/HSW
  * MPEG-2 encoding on IVB/HSW
  * Video process on ILK/SNB/IVB/HSW
  * Implement vaQuerySurfaceAttributes()
  * Implement the new version of vaCreateSurfaces()
  * Optimize H.264 encoding on IVB/HSW
- Bump the libdrm and libva as per upstream change
* Tue Mar 19 2013 kkhere.geo@gmail.com
- Version 1.0.20 - 18.Mar.2013
  * Add support for wayland 1.0 protocol (Rob Bradford)
  * Add global alpha support for subpicture
  * Add support for IA88/AI88 subpicture
  * Support up to 4 subpictures for each VA surface
  * Update PCI IDs for Haswell CRW
  * Automake 1.13 fixups (Armin K)
  * Fix libva-intel-driver-1.0.19 display corruption on IVB GT1
    https://bugs.freedesktop.org/show_bug.cgi?id=57323
  * Fix decoding with FREXT02_JVC_C.264 on SNB
    https://bugs.freedesktop.org/show_bug.cgi?id=57720
  * Fix H.264 decoding broken/visual errors on ILK (Tobias Jakobi)
    https://bugs.freedesktop.org/show_bug.cgi?id=58875
  * Fix GPU hung with h.264 video and a resolution of 1920x816 on IVB
    https://bugs.freedesktop.org/show_bug.cgi?id=59050
* Fri Nov  9 2012 kkhere.geo@gmail.com
- update to release 1.0.19
  Version 1.0.19 - 09.Nov.2012
  * Add support for Haswell
  * Add raw DRM support (Dmitry Ermilov)
  * Add Wayland support
  * Add support for display rotation attribute
  * Support 4K encoding on IVB and HSW
  * Drop explicit dependency on X11 and libva-x11
  * Fix VC-1 decoding when VSTRANSFORM is 0
  * Fix SIGSEGV caused by use-after-free of the bufmgr (Stéphane Marchesin)
  * Fix thread safety issue (Gautam)
  * Fix vaUnlockSurface() for libva trace
* Thu Oct 18 2012 kkhere.geo@gmail.com
- update to git master commit b6dd872 as released version does not
  build with the latest libva release
* Wed Jul 11 2012 adrian@suse.de
- exclusive arch for %%ix86 and x86_64
* Fri Jun  1 2012 sndirsch@suse.com
- remove hw Supplements (bnc#764395)
* Wed May 30 2012 crrodriguez@opensuse.org
- Reduce buildRequires to the minimum needed now that
  the dependency chain has been fixed.
* Tue May 29 2012 kkhere.geo@gmail.com
- Update to upstream release 1.0.18
  * Fixes for SandyBridge and IvyBridge, full changelog at
    http://cgit.freedesktop.org/vaapi/intel-driver/
* Fri May 25 2012 sndirsch@suse.com
- license needed to be changed to "MIT and EPL-1.0" (bnc#764135)
* Wed May 23 2012 kkhere.geo@gmail.com
- Convert BuildRequires to pkgconfig(...)
- Build the released version not a git snapshot
- Correct source file name to match the source URL
- Rename package libva-intel-driver to vaapi-intel-driver for
  consistancy with vaapi-dummy-driver
* Tue May 22 2012 crrodriguez@opensuse.org
- Fix/reduce buildRequires, still unneded builddeps due to
  bug in libva-devel ..
* Tue May 22 2012 crrodriguez@opensuse.org
- Initial package for factory, version 1.0.17_git201205040307.
